#!/bin/bash
#########################################################################
#
#  Motopocalypse: Motorola bootloader unlock script
#  Linux/OS X version
#
#  Copyright (C) 2013 Dan Rosenberg (@djrbliss)
#
#########################################################################
#
# Instructions:
#
#  1. Ensure your device has been rooted and you have a working "su"
#     installation.
#
#  2. Put your device in debugging mode
#
#  3. Attach it via USB
#
#  4. Run this script in the same directory as the rest of the extracted
#     zipfile
#
#########################################################################

echo "[*]"
echo "[*] Motopocalypse: Motorola bootloader unlock script (Linux/OS X version)"
echo "[*] v1.0"
echo "[*] by Dan Rosenberg (@djrbliss)"
echo "[*]"
echo "[*] Supports the Motorola Razr HD, Razr M, Razr Maxx HD, and Atrix HD."
echo "[*]"
echo "[*] Before continuing, ensure that your device has been rooted and you have"
echo "[*] a working "su" installation, that USB debugging is enabled, "
echo "[*] and that your phone is connected via USB."
echo "[*]"
echo "[*] WARNING: This will permanently void the warranty on your device. This"
echo "[*] is not reversible. I am not responsible for any damage to your phone"
echo "[*] as a result using this tool."
echo "[*]"
echo "[*] Press enter to root your phone..."

read -n 1

echo "[*]"

platform=`uname`
if [ $(uname -p) = 'powerpc' ]; then
        echo "[-] PowerPC is not supported."
        exit 1
fi

if [ "$platform" = 'Darwin' ]; then
        adb="./adb.osx"
        fastboot="./fastboot.osx"
        version="OS X"
else
        adb="./adb.linux"
        fastboot="./fastboot.linux"
        version="Linux"
fi
chmod +x $adb
chmod +x $fastboot

$adb kill-server

echo "[*] Waiting for device..."
$adb wait-for-device

echo "[*] Device found."

echo "[*] Pushing unlock tool..."
$adb push unlock /data/local/tmp
$adb shell chmod 755 /data/local/tmp/unlock

echo "[*] Unlocking phone..."
$adb shell su -c /data/local/tmp/unlock

echo "[*] Cleaning up..."
$adb shell rm /data/local/tmp/unlock

echo "[*] Unlocking complete. Rebooting into bootloader mode."
$adb reboot bootloader
echo "[*] Press enter once the phone has rebooted into bootloader mode."

read -n 1

echo "[*] Displaying bootloader variables:"
$fastboot getvar all

echo "[*] Press enter to reboot and exit."

read -n 1
$fastboot continue
$adb kill-server
